==> rainbows-4.0.0.tar.gz: rainbows-4.0.0/CHANGELOG.md <==
# Changelog

## 4.0.0 (2024-12-06)

Full Changelog: [v3.0.0...v4.0.0](https://github.com/pilfo/rainbows/compare/v3.0.0...v4.0.0)

### Features

* **api:** update via SDK Studio ([eef5ee6](https://github.com/pilfo/rainbows/commit/eef5ee6b3738745897b6737a84004620d60cbfd0))
* **api:** update via SDK Studio ([085b462](https://github.com/pilfo/rainbows/commit/085b46261f3f662f1f355e8d49fbaf8557c166b4))
* **api:** update via SDK Studio ([454aa3e](https://github.com/pilfo/rainbows/commit/454aa3e8ec9f5297dc1c26218e9a7eac8f28d807))
* **api:** update via SDK Studio ([3e5ee1e](https://github.com/pilfo/rainbows/commit/3e5ee1ebc964eb8e81e1611871e6a294624beb72))
* **api:** update via SDK Studio ([#25](https://github.com/pilfo/rainbows/issues/25)) ([f48ad1c](https://github.com/pilfo/rainbows/commit/f48ad1c751059196e07cd3d0161bbd855bbc69ed))
* **api:** update via SDK Studio ([#26](https://github.com/pilfo/rainbows/issues/26)) ([2f720cc](https://github.com/pilfo/rainbows/commit/2f720cc6b71f5ec97f477a288db243609978035a))
* **api:** update via SDK Studio ([#28](https://github.com/pilfo/rainbows/issues/28)) ([741df9d](https://github.com/pilfo/rainbows/commit/741df9dce5f2da19aa29bc8698de2eaad73bc4f6))
* **api:** update via SDK Studio ([#29](https://github.com/pilfo/rainbows/issues/29)) ([648fac2](https://github.com/pilfo/rainbows/commit/648fac2b7546ecf4a7db5d463ed2b72a37e3ca9f))


### Bug Fixes

* **client:** compat with new httpx 0.28.0 release ([#21](https://github.com/pilfo/rainbows/issues/21)) ([afb2abd](https://github.com/pilfo/rainbows/commit/afb2abd3253742b46b0dea59578ac0bd6c8be8c2))


### Chores

* go live ([#2](https://github.com/pilfo/rainbows/issues/2)) ([13a14bc](https://github.com/pilfo/rainbows/commit/13a14bce87d695e747b9deecbcc962763c62dd7d))
* go live ([#22](https://github.com/pilfo/rainbows/issues/22)) ([1177b69](https://github.com/pilfo/rainbows/commit/1177b696942a9cb78be2aee7482d9c22b6198f33))
* **internal:** codegen related update ([#19](https://github.com/pilfo/rainbows/issues/19)) ([d95a538](https://github.com/pilfo/rainbows/commit/d95a538217baa7521413615973dad90dd4313ea4))
* **internal:** exclude mypy from running on tests ([#20](https://github.com/pilfo/rainbows/issues/20)) ([66e0b10](https://github.com/pilfo/rainbows/commit/66e0b10083f4dc74a7e96b0af309589e96c33d03))
* **internal:** fix compat model_dump method when warnings are passed ([#17](https://github.com/pilfo/rainbows/issues/17)) ([ea30ea1](https://github.com/pilfo/rainbows/commit/ea30ea1765d516025d7f8a113f314e023a0d488b))
* rebuild project due to codegen change ([#12](https://github.com/pilfo/rainbows/issues/12)) ([657d05f](https://github.com/pilfo/rainbows/commit/657d05f4da1d9df2c3de7bc6f8d53fb4da085744))
* rebuild project due to codegen change ([#14](https://github.com/pilfo/rainbows/issues/14)) ([f6b59c3](https://github.com/pilfo/rainbows/commit/f6b59c3b36a18de2ca63f7bb44437cf0aa28ae45))
* rebuild project due to codegen change ([#15](https://github.com/pilfo/rainbows/issues/15)) ([e378f2c](https://github.com/pilfo/rainbows/commit/e378f2c155255230d874c67adee2ddb29b7590ea))
* rebuild project due to codegen change ([#16](https://github.com/pilfo/rainbows/issues/16)) ([f0b9f97](https://github.com/pilfo/rainbows/commit/f0b9f9715fa4859174aed4543315b6b68eb9700e))
* update SDK settings ([8889782](https://github.com/pilfo/rainbows/commit/888978214d75579dde54f49c57dfa66e7ec8546e))


### Documentation

* add info log level to readme ([#18](https://github.com/pilfo/rainbows/issues/18)) ([7a3a24f](https://github.com/pilfo/rainbows/commit/7a3a24ffa2557d42354afc18f06b8efbf8d3579d))

## 3.0.0 (2024-09-18)

Full Changelog: [v2.0.0...v3.0.0](https://github.com/pilfo/rainbows/compare/v2.0.0...v3.0.0)

### Features

* **api:** update via SDK Studio ([801f471](https://github.com/pilfo/rainbows/commit/801f4715d5d4b53d3a5c6606d69fc806dfa2bf34))
* **api:** update via SDK Studio ([2ef1f5a](https://github.com/pilfo/rainbows/commit/2ef1f5a0ba9cf9993d7b933a00083d3ac81e6cbe))


### Chores

* go live ([#8](https://github.com/pilfo/rainbows/issues/8)) ([db4f167](https://github.com/pilfo/rainbows/commit/db4f167dd2593e08d687f18e66d98c7d6966e2cf))
* update SDK settings ([#10](https://github.com/pilfo/rainbows/issues/10)) ([133f843](https://github.com/pilfo/rainbows/commit/133f843e3e1c1bc242ef4bdc5c14044eaae7f6e1))

## 2.0.0 (2024-09-18)

Full Changelog: [v0.0.1-alpha.0...v2.0.0](https://github.com/pilfo/rainbows/compare/v0.0.1-alpha.0...v2.0.0)

### Chores

* go live ([#4](https://github.com/pilfo/rainbows/issues/4)) ([93cd5cd](https://github.com/pilfo/rainbows/commit/93cd5cd6ca0e8aa4d7dc46e25a8a59a3e3cb061a))
* update SDK settings ([#6](https://github.com/pilfo/rainbows/issues/6)) ([89c8d53](https://github.com/pilfo/rainbows/commit/89c8d53c10207c04b30a38352207e304da837b58))

==> rainbows-4.1.0.tar.gz: rainbows-4.1.0/CHANGELOG.md <==
# Changelog

## 4.1.0 (2024-12-06)

Full Changelog: [v4.0.0...v4.1.0](https://github.com/pilfo/rainbows/compare/v4.0.0...v4.1.0)

### Features

* **api:** update via SDK Studio ([#4](https://github.com/pilfo/rainbows/issues/4)) ([0751e67](https://github.com/pilfo/rainbows/commit/0751e67566f4d80c606a27beb7109275eccb5197))

## 4.0.0 (2024-12-06)

Full Changelog: [v3.0.0...v4.0.0](https://github.com/pilfo/rainbows/compare/v3.0.0...v4.0.0)

### Features

* **api:** update via SDK Studio ([eef5ee6](https://github.com/pilfo/rainbows/commit/eef5ee6b3738745897b6737a84004620d60cbfd0))
* **api:** update via SDK Studio ([085b462](https://github.com/pilfo/rainbows/commit/085b46261f3f662f1f355e8d49fbaf8557c166b4))
* **api:** update via SDK Studio ([454aa3e](https://github.com/pilfo/rainbows/commit/454aa3e8ec9f5297dc1c26218e9a7eac8f28d807))
* **api:** update via SDK Studio ([3e5ee1e](https://github.com/pilfo/rainbows/commit/3e5ee1ebc964eb8e81e1611871e6a294624beb72))
* **api:** update via SDK Studio ([#25](https://github.com/pilfo/rainbows/issues/25)) ([f48ad1c](https://github.com/pilfo/rainbows/commit/f48ad1c751059196e07cd3d0161bbd855bbc69ed))
* **api:** update via SDK Studio ([#26](https://github.com/pilfo/rainbows/issues/26)) ([2f720cc](https://github.com/pilfo/rainbows/commit/2f720cc6b71f5ec97f477a288db243609978035a))
* **api:** update via SDK Studio ([#28](https://github.com/pilfo/rainbows/issues/28)) ([741df9d](https://github.com/pilfo/rainbows/commit/741df9dce5f2da19aa29bc8698de2eaad73bc4f6))
* **api:** update via SDK Studio ([#29](https://github.com/pilfo/rainbows/issues/29)) ([648fac2](https://github.com/pilfo/rainbows/commit/648fac2b7546ecf4a7db5d463ed2b72a37e3ca9f))


### Bug Fixes

* **client:** compat with new httpx 0.28.0 release ([#21](https://github.com/pilfo/rainbows/issues/21)) ([afb2abd](https://github.com/pilfo/rainbows/commit/afb2abd3253742b46b0dea59578ac0bd6c8be8c2))


### Chores

* go live ([#2](https://github.com/pilfo/rainbows/issues/2)) ([13a14bc](https://github.com/pilfo/rainbows/commit/13a14bce87d695e747b9deecbcc962763c62dd7d))
* go live ([#22](https://github.com/pilfo/rainbows/issues/22)) ([1177b69](https://github.com/pilfo/rainbows/commit/1177b696942a9cb78be2aee7482d9c22b6198f33))
* **internal:** codegen related update ([#19](https://github.com/pilfo/rainbows/issues/19)) ([d95a538](https://github.com/pilfo/rainbows/commit/d95a538217baa7521413615973dad90dd4313ea4))
* **internal:** exclude mypy from running on tests ([#20](https://github.com/pilfo/rainbows/issues/20)) ([66e0b10](https://github.com/pilfo/rainbows/commit/66e0b10083f4dc74a7e96b0af309589e96c33d03))
* **internal:** fix compat model_dump method when warnings are passed ([#17](https://github.com/pilfo/rainbows/issues/17)) ([ea30ea1](https://github.com/pilfo/rainbows/commit/ea30ea1765d516025d7f8a113f314e023a0d488b))
* rebuild project due to codegen change ([#12](https://github.com/pilfo/rainbows/issues/12)) ([657d05f](https://github.com/pilfo/rainbows/commit/657d05f4da1d9df2c3de7bc6f8d53fb4da085744))
* rebuild project due to codegen change ([#14](https://github.com/pilfo/rainbows/issues/14)) ([f6b59c3](https://github.com/pilfo/rainbows/commit/f6b59c3b36a18de2ca63f7bb44437cf0aa28ae45))
* rebuild project due to codegen change ([#15](https://github.com/pilfo/rainbows/issues/15)) ([e378f2c](https://github.com/pilfo/rainbows/commit/e378f2c155255230d874c67adee2ddb29b7590ea))
* rebuild project due to codegen change ([#16](https://github.com/pilfo/rainbows/issues/16)) ([f0b9f97](https://github.com/pilfo/rainbows/commit/f0b9f9715fa4859174aed4543315b6b68eb9700e))
* update SDK settings ([8889782](https://github.com/pilfo/rainbows/commit/888978214d75579dde54f49c57dfa66e7ec8546e))


### Documentation

* add info log level to readme ([#18](https://github.com/pilfo/rainbows/issues/18)) ([7a3a24f](https://github.com/pilfo/rainbows/commit/7a3a24ffa2557d42354afc18f06b8efbf8d3579d))

## 3.0.0 (2024-09-18)

Full Changelog: [v2.0.0...v3.0.0](https://github.com/pilfo/rainbows/compare/v2.0.0...v3.0.0)

### Features

* **api:** update via SDK Studio ([801f471](https://github.com/pilfo/rainbows/commit/801f4715d5d4b53d3a5c6606d69fc806dfa2bf34))
* **api:** update via SDK Studio ([2ef1f5a](https://github.com/pilfo/rainbows/commit/2ef1f5a0ba9cf9993d7b933a00083d3ac81e6cbe))


### Chores

* go live ([#8](https://github.com/pilfo/rainbows/issues/8)) ([db4f167](https://github.com/pilfo/rainbows/commit/db4f167dd2593e08d687f18e66d98c7d6966e2cf))
* update SDK settings ([#10](https://github.com/pilfo/rainbows/issues/10)) ([133f843](https://github.com/pilfo/rainbows/commit/133f843e3e1c1bc242ef4bdc5c14044eaae7f6e1))

## 2.0.0 (2024-09-18)

Full Changelog: [v0.0.1-alpha.0...v2.0.0](https://github.com/pilfo/rainbows/compare/v0.0.1-alpha.0...v2.0.0)

### Chores

* go live ([#4](https://github.com/pilfo/rainbows/issues/4)) ([93cd5cd](https://github.com/pilfo/rainbows/commit/93cd5cd6ca0e8aa4d7dc46e25a8a59a3e3cb061a))
* update SDK settings ([#6](https://github.com/pilfo/rainbows/issues/6)) ([89c8d53](https://github.com/pilfo/rainbows/commit/89c8d53c10207c04b30a38352207e304da837b58))
